<!doctype html>
<html>
  <head>
    <meta charset="utf-8">
    
    <!-- Always force latest IE rendering engine or request Chrome Frame -->
    <meta content="IE=edge,chrome=1" http-equiv="X-UA-Compatible">
    
    <title>URL Shortener</title>
    
    <link type="text/css" rel="stylesheet" href="/static/stylesheets/bootstrap.css" media="screen" />
    <link type="text/css" rel="stylesheet" href="/static/stylesheets/bootstrap-responsive.css" media="screen" />
  </head>
  
  <body>

    <div class="navbar navbar-inverse">
      <div class="navbar-inner">
	<div class="container-fluid">
	  <a class="brand" href="#">URL Shortener</a>
	</div>
      </div>
    </div>

    {% block body %}
    {% endblock body %}

    {% block scripts %}
    {% endblock scripts %}
  </body>
</html>
