{% extends 'layouts/default.html' %}

{% block body %}
<div class="row-fluid">

  <div class="span6 offset4">
    <blockquote>
      <p>Invalid data was supplied to the URL shortener</p>
    </blockquote>
    
    <ul class="nav nav-pills">
      <li><a href="/">take me home</a></li>
    </ul>
  </div>
</div>
{% endblock body %}
